<?php

// forceMods plugin
// (c) schmidi 2011
// www.doh-nuts.at



// v0.5 beta
// complete rewrite

// v0.4
// load settings even if disabled

// v0.3
// forceMods reworked
// new config-layout (easier to config i hope)
// added manialink-windows (...need some improvement)
// added settings-reload

// v0.2
// added chat-commands
// little improvements
 
// v0.1
// initial release
// thx to Yorkshire @ tm-forum.com


require_once('forceMods/FMod.php');
require_once('forceMods/FModList.php');

class ForceMods {

	protected $aseco = false;
	
	// mode: off=0 sequential=1 random=2
	protected $mode = 1;
	protected $mods = array();
	protected $override = false;

	protected $modLists = array();
	public static $environments = array();

	
	function onSync($aseco) {
		$this->aseco = &$aseco;
		
		switch($aseco->server->game) {
			case 'ManiaPlanet':
				self::$environments = array(1 => 'Canyon');
				break;
		}
		
		// 1 list per enviroment
		foreach(self::$environments as $id => $name) {
			$this->modLists[$id] = new FModList();
		}

		$this->loadSettings('forceMods.xml');
	}


	function onEndMap($aseco, $race) {
		if($this->mode == 0) {
			return;
		}
		
		$challenge = &$race[1];
		$restart = &$race[4];

		$aseco->client->query('GetNextChallengeInfo');
		$nextChallenge = $aseco->client->getResponse();
		
		$env = $nextChallenge['Environnement'];
		if($restart == 1) {
			$env = $challenge['Environnement'];
		}

		$id = array_search($env, self::$environments);

		if($id === false) {
			$this->console('[forceMods] Enviroment "' . $env . '" not defined, canceling...');
			return;
		}

		$modList = &$this->modLists[$id];
		$index = $modList->nextMod($this->mode == 2);

		if($index < 0) {
			$this->console('[forceMods] No mods defined (enabled) for this environment, canceling...');
			$aseco->client->query('SetForcedMods', false, array());
			return;
		}

		$aseco->client->query('SetForcedMods', $this->override, array(array('Env' => $env, 'Url' => $modList->getUrl())));
		$result = $aseco->client->getResponse();
		
		if($result === true) {
			$this->console('[forceMods] Enabling mod: ' . $env . ' > ' . $modList->getName());
		}
		else {
			$this->console('[forceMods] ' . $result['faultString'] . '(ErrorCode: ' . $result['faultCode'] . ')');
		}
	}
	
	
	private function loadSettings($file) {
		if (($xml = @simplexml_load_file($file)) === false) {
			$this->console('[forceMods] Could not read/parse config file ' . $file . ' !');
			die();
		}
		
		$this->mode = intval($xml->mode);
		$this->mode = ($this->mode >= 0 && $this->mode <= 2) ? $this->mode : 0;
		$this->override = (strtolower($xml->override) == 'true' || $xml->override == '1') ? true : false;
		
		foreach ($xml->mod as $mod) {

			if (!isset($mod['name']) || !isset($mod['url'])) {
				continue;
			}
			
			$fmod = new FMod($mod['name'], $mod['url'], $mod['enabled']);

			if(isset($mod['env']) && $mod['env'] != '') {
				// add mod to specified environments
				$str = $mod['env'];
				$i = strlen($mod['env']) - 1;
				while($i >= 0) {
					$c = intval($str[$i]);
					if(array_key_exists($c, self::$environments)) {
						$this->modLists[intval($c)]->addMod($fmod);
					}
					$i--;
				}
			}
			else {
				// add mod to all environments
				foreach(self::$environments as $id => $name) {
					$this->modLists[$id]->addMod($fmod);
				}
			}
		}
	}


	private function console($txt) {
		$this->aseco->console($txt);
	}
	
}


$FORCEMODS = new ForceMods();

Aseco::registerEvent('onSync', array($FORCEMODS, 'onSync'));
Aseco::registerEvent('onEndMap', array($FORCEMODS, 'onEndMap'));

?>